"use strict";
var tslib_1 = require("tslib");
var crypto_1 = (0, tslib_1.__importDefault)(require("crypto"));
var fs_1 = (0, tslib_1.__importDefault)(require("fs"));
var path_1 = (0, tslib_1.__importDefault)(require("path"));
var test_at_scale_core_1 = require("@lambdatest/test-at-scale-core");
var constants_1 = require("./constants");
var JestDiscoverReporter = /** @class */ (function () {
    function JestDiscoverReporter(globalConfig) {
        this._globalConfig = globalConfig;
        this.tests = [];
        this.testSuites = new Map();
        this.testsDependenciesMap = null;
    }
    JestDiscoverReporter.prototype.onTestResult = function (test, testResult) {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function () {
            var repoID, commitID, testDeps;
            var _this = this;
            return (0, tslib_1.__generator)(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        repoID = process.env.REPO_ID;
                        commitID = process.env.COMMIT_ID;
                        return [4 /*yield*/, test_at_scale_core_1.Util.listDependency(test.path, test_at_scale_core_1.Util.REPO_ROOT, false, test.context.config)];
                    case 1:
                        testDeps = _a.sent();
                        if (testDeps !== null) {
                            if (this.testsDependenciesMap === null) {
                                this.testsDependenciesMap = new Map();
                            }
                            this.testsDependenciesMap.set(testDeps.testFile, new Set(testDeps.dependsOn));
                        }
                        testResult.testResults.forEach(function (jestTest) {
                            var filename = test.path;
                            var testIdentifier = test_at_scale_core_1.Util.getIdentifier(filename, jestTest.title);
                            var ancestorTitles = jestTest.ancestorTitles;
                            var suiteIdentifiers = ancestorTitles.map(function (suiteName) { return test_at_scale_core_1.Util.getIdentifier(filename, suiteName); });
                            var tasTest = new test_at_scale_core_1.Test(crypto_1.default
                                .createHash("md5")
                                .update(repoID + "\n" + suiteIdentifiers.join("\n") + "\n" + testIdentifier)
                                .digest("hex"), testIdentifier, jestTest.title, suiteIdentifiers.length > 0
                                ? crypto_1.default
                                    .createHash("md5")
                                    .update(repoID + "\n" + suiteIdentifiers.join("\n"))
                                    .digest("hex")
                                : null, commitID, path_1.default.relative(test_at_scale_core_1.Util.REPO_ROOT, filename), test_at_scale_core_1.Util.getLocator(filename, ancestorTitles, jestTest.title));
                            _this.tests.push(tasTest);
                            for (var i = 0; i < ancestorTitles.length; i++) {
                                var suiteTitle = ancestorTitles[i];
                                var thisSuiteIdentifiers = suiteIdentifiers.slice(0, i + 1);
                                var parentSuiteIdentifiers = thisSuiteIdentifiers.slice(0, -1);
                                var suiteIdentifier = test_at_scale_core_1.Util.getIdentifier(filename, suiteTitle);
                                var testSuite = new test_at_scale_core_1.TestSuite(crypto_1.default.createHash("md5").update(repoID + "\n" + thisSuiteIdentifiers.join("\n")).digest("hex"), suiteIdentifier, parentSuiteIdentifiers.length > 0
                                    ? crypto_1.default
                                        .createHash("md5")
                                        .update(repoID + "\n" + parentSuiteIdentifiers.join("\n"))
                                        .digest("hex")
                                    : null);
                                _this.testSuites.set(testSuite.suiteID, testSuite);
                            }
                        });
                        return [2 /*return*/];
                }
            });
        });
    };
    JestDiscoverReporter.prototype.onRunComplete = function () {
        return (0, tslib_1.__awaiter)(this, void 0, void 0, function () {
            var repoID, buildID, taskID, orgID, branch, commitID, discoveryResult;
            return (0, tslib_1.__generator)(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        repoID = process.env.REPO_ID;
                        buildID = process.env.BUILD_ID;
                        taskID = process.env.TASK_ID;
                        orgID = process.env.ORG_ID;
                        branch = process.env.BRANCH_NAME;
                        commitID = process.env.COMMIT_ID;
                        discoveryResult = new test_at_scale_core_1.DiscoveryResult(this.tests, Array.from(this.testSuites.values()), [], // impacted tests empty for now
                        repoID, commitID, buildID, taskID, orgID, branch);
                        // Ensure output path exists
                        fs_1.default.mkdirSync(path_1.default.dirname(constants_1.DISCOVERY_RESULT_FILE), { recursive: true });
                        // Write data to file
                        return [4 /*yield*/, test_at_scale_core_1.JSONStream.stringify(discoveryResult, fs_1.default.createWriteStream(constants_1.DISCOVERY_RESULT_FILE))];
                    case 1:
                        // Write data to file
                        _a.sent();
                        fs_1.default.mkdirSync(path_1.default.dirname(constants_1.TESTS_DEPENDENCIES_MAP_FILE), { recursive: true });
                        return [4 /*yield*/, test_at_scale_core_1.JSONStream.stringify(this.testsDependenciesMap, fs_1.default.createWriteStream(constants_1.TESTS_DEPENDENCIES_MAP_FILE), test_at_scale_core_1.JSONStream.replacer)];
                    case 2:
                        _a.sent();
                        return [2 /*return*/];
                }
            });
        });
    };
    return JestDiscoverReporter;
}());
module.exports = JestDiscoverReporter;
//# sourceMappingURL=jest-discover-reporter.js.map